# three-react-obj-loader
Three.js OBJLoader as an ES6 Module - class OBJLoader - tested with Node + React + Babel 

## Install
NPM Package
```
$ npm install --save three-react-obj-loader
```

Import on script
```
import MTLLoader from 'three-react-mtl-loader';
```

## Usage on React Components
```
import React, { Component } from 'react';
import * as THREE from 'three';
import OBJLoader from "three-react-obj-loader";
import MTLLoader from 'three-react-mtl-loader';

let renderer, scene, camera;

class ObjViewer extends Component {
  constructor(props) {
    super(props);
  }

  componentDidMount() {

    scene = new THREE.Scene();
    camera = new THREE.PerspectiveCamera(50, 500 / 400, 0.1, 1000);

    renderer = new THREE.WebGLRenderer({ canvas: this.refs.threeCanvas, alpha: true });
    renderer.setSize(500, 400);

    camera.position.z = 10;

    var mtlLoader = new MTLLoader();
    mtlLoader.load('/path-to-model/model.mtl', function (materials) {
      materials.preload();

      var objLoader = new OBJLoader();
      objLoader.setMaterials(materials);

      objLoader.load('/path-to-model/model.obj', function (object) {
        object.position.y = -3;
        scene.add(object);
      });

    });

    var light = new THREE.DirectionalLight(0xffffff, 1);
    light.position.set(1, 1, 1).normalize();
    scene.add(light);

    this._render();
  }

  _render = () => {
    requestAnimationFrame(this._render);
    renderer.render(scene, camera);
  }

  render() {
    return (
      <div>
        <canvas ref="threeCanvas">
        </canvas>
      </div>
    );
  }
}

export default ObjViewer;
```